@@ -23,12 +23,10 @@ class TrainingsDownloader():
         return training_data
 
     async def download_images_and_annotations(self, basic_data: BasicData, image_folder: str) -> TrainingData:
-        image_data_task = create_task(self.downloader.download_images_data(basic_data.image_ids))
         await self.downloader.download_images(basic_data.image_ids, image_folder)
-
-        training_data = TrainingData(image_data=[], categories={c['name']: c['id'] for c in basic_data.categories})
-        image_data = await image_data_task
+        image_data = await self.downloader.download_images_data(basic_data.image_ids)
         logging.info('filtering corrupt images')  # download only safes valid images
+        training_data = TrainingData(image_data=[], categories={c['name']: c['id'] for c in basic_data.categories})
         for i in image_data:
             if os.path.isfile(f'{image_folder}/{i["id"]}.jpg'):
                 training_data.image_data.append(i)
